@@ -12,17 +12,19 @@ class AchievementEngine(object):
         (obj, created) = Achievement.objects.get_or_create(key=cls.key,  defaults={
             'name': cls.name,
             'description': cls.description,
-            'category': cls.category,
             'bonus': cls.bonus,
             'callback': construct_callback(cls)})
         if not created:
             # update the object if key didn't change :
             obj.name = cls.name
             obj.description = cls.description
-            obj.category = cls.category
             obj.bonus = cls.bonus
             obj.callback = construct_callback(cls)
             obj.save()
+        # optional category
+        if cls.category:
+            obj.category = cls.category
+            obj.save()
         achievement_registered.send(sender=self, achievement_class=cls)
 
     def check_achievement(self, user, key, *args, **kwargs):
